@@ -31,14 +31,13 @@ if False:
 # by default, all DeprecationWarning under sphinx package will be emit.
 # Users can avoid this by using environment variable: PYTHONWARNINGS=
 if 'PYTHONWARNINGS' not in os.environ:
-    warnings.filterwarnings('default',
-                            category=RemovedInNextVersionWarning, module='sphinx')
+    warnings.filterwarnings('default', category=RemovedInNextVersionWarning)
 # docutils.io using mode='rU' for open
 warnings.filterwarnings('ignore', "'U' mode is deprecated",
                         DeprecationWarning, module='docutils.io')
 
-__version__ = '1.8.1'
-__released__ = '1.8.1'  # used when Sphinx builds its own docs
+__version__ = '1.8.3'
+__released__ = '1.8.3'  # used when Sphinx builds its own docs
 
 #: Version info for better programmatic use.
 #:
@@ -48,7 +47,7 @@ __released__ = '1.8.1'  # used when Sphinx builds its own docs
 #:
 #: .. versionadded:: 1.2
 #:    Before version 1.2, check the string ``sphinx.__version__``.
-version_info = (1, 8, 1, 'final', 0)
+version_info = (1, 8, 3, 'final', 0)
 
 package_dir = path.abspath(path.dirname(__file__))
 
