@@ -11,9 +11,16 @@
 
 from docutils import nodes
 
+from sphinx.locale import __
 from sphinx.util import logging
 from sphinx.util.nodes import clean_astext
 
+if False:
+    # For type annotation
+    from typing import Any, Dict  # NOQA
+    from sphinx.application import Sphinx  # NOQA
+
+
 logger = logging.getLogger(__name__)
 
 if False:
@@ -37,8 +44,8 @@ def register_sections_as_label(app, document):
         sectname = clean_astext(node[0])
 
         if name in labels:
-            logger.warning('duplicate label %s, ' % name + 'other instance '
-                           'in ' + app.env.doc2path(labels[name][0]),
+            logger.warning(__('duplicate label %s, other instance in %s'),
+                           name, app.env.doc2path(labels[name][0]),
                            location=node)
 
         anonlabels[name] = docname, labelid
