@@ -10,7 +10,6 @@
 """
 
 from os import path
-from typing import TYPE_CHECKING
 
 from docutils import nodes
 from docutils.io import StringInput
@@ -18,7 +17,7 @@ from docutils.utils import relative_path
 
 from sphinx import addnodes
 from sphinx.domains.std import make_glossary_term, split_term_classifiers
-from sphinx.locale import init as init_locale
+from sphinx.locale import __, init as init_locale
 from sphinx.transforms import SphinxTransform
 from sphinx.util import split_index_msg, logging
 from sphinx.util.i18n import find_catalog
@@ -28,7 +27,8 @@ from sphinx.util.nodes import (
 )
 from sphinx.util.pycompat import indent
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Dict, List, Tuple  # NOQA
     from sphinx.application import Sphinx  # NOQA
     from sphinx.config import Config  # NOQA
@@ -51,10 +51,10 @@ def publish_msgstr(app, source, source_path, source_line, config, settings):
     """
     from sphinx.io import SphinxI18nReader
     reader = SphinxI18nReader(app)
-    reader.set_lineno_for_reporter(source_line)
-    parser = app.registry.create_source_parser(app, '')
+    parser = app.registry.create_source_parser(app, 'restructuredtext')
     doc = reader.read(
-        source=StringInput(source=source, source_path=source_path),
+        source=StringInput(source=source,
+                           source_path="%s:%s:<translated>" % (source_path, source_line)),
         parser=parser,
         settings=settings,
     )
@@ -86,12 +86,13 @@ class Locale(SphinxTransform):
     def apply(self):
         # type: () -> None
         settings, source = self.document.settings, self.document['source']
+        msgstr = u''
+
         # XXX check if this is reliable
         assert source.startswith(self.env.srcdir)
         docname = path.splitext(relative_path(path.join(self.env.srcdir, 'dummy'),
                                               source))[0]
-        textdomain = find_catalog(docname,
-                                  self.document.settings.gettext_compact)
+        textdomain = find_catalog(docname, self.config.gettext_compact)
 
         # fetch translations
         dirs = [path.join(self.env.srcdir, directory)
@@ -102,7 +103,7 @@ class Locale(SphinxTransform):
 
         # phase1: replace reference ids with translated names
         for node, msg in extract_messages(self.document):
-            msgstr = catalog.gettext(msg)
+            msgstr = catalog.gettext(msg)  # type: ignore
             # XXX add marker to untranslated parts
             if not msgstr or msgstr == msg or not msgstr.strip():
                 # as-of-yet untranslated
@@ -219,7 +220,7 @@ class Locale(SphinxTransform):
             if node.get('translated', False):  # to avoid double translation
                 continue  # skip if the node is already translated by phase1
 
-            msgstr = catalog.gettext(msg)
+            msgstr = catalog.gettext(msg)  # type: ignore
             # XXX add marker to untranslated parts
             if not msgstr or msgstr == msg:  # as-of-yet untranslated
                 continue
@@ -247,19 +248,37 @@ class Locale(SphinxTransform):
             if isinstance(node, LITERAL_TYPE_NODES):
                 msgstr = '::\n\n' + indent(msgstr, ' ' * 3)
 
+            # Structural Subelements phase1
+            # There is a possibility that only the title node is created.
+            # see: http://docutils.sourceforge.net/docs/ref/doctree.html#structural-subelements
+            if isinstance(node, nodes.title):
+                # This generates: <section ...><title>msgstr</title></section>
+                msgstr = msgstr + '\n' + '-' * len(msgstr) * 2
+
             patch = publish_msgstr(self.app, msgstr, source,
                                    node.line, self.config, settings)
-            # XXX doctest and other block markup
-            if not isinstance(
-                    patch,
-                    (nodes.paragraph,) + LITERAL_TYPE_NODES + IMAGE_TYPE_NODES):
-                continue  # skip for now
+
+            # Structural Subelements phase2
+            if isinstance(node, nodes.title):
+                # get <title> node that placed as a first child
+                patch = patch.next_node()
+
+            # ignore unexpected markups in translation message
+            if not isinstance(patch, (
+                              (nodes.paragraph,  # expected form of translation
+                               nodes.title,  # generated by above "Subelements phase2"
+                               ) +
+                              # following types are expected if
+                              # config.gettext_additional_targets is configured
+                              LITERAL_TYPE_NODES +
+                              IMAGE_TYPE_NODES
+                              )):
+                continue  # skip
 
             # auto-numbered foot note reference should use original 'ids'.
-            def is_autonumber_footnote_ref(node):
+            def is_autofootnote_ref(node):
                 # type: (nodes.Node) -> bool
-                return isinstance(node, nodes.footnote_reference) and \
-                    node.get('auto') == 1
+                return isinstance(node, nodes.footnote_reference) and node.get('auto')
 
             def list_replace_or_append(lst, old, new):
                 # type: (List, Any, Any) -> None
@@ -267,13 +286,13 @@ class Locale(SphinxTransform):
                     lst[lst.index(old)] = new
                 else:
                     lst.append(new)
-            old_foot_refs = node.traverse(is_autonumber_footnote_ref)
-            new_foot_refs = patch.traverse(is_autonumber_footnote_ref)
+            old_foot_refs = node.traverse(is_autofootnote_ref)
+            new_foot_refs = patch.traverse(is_autofootnote_ref)
             if len(old_foot_refs) != len(new_foot_refs):
                 old_foot_ref_rawsources = [ref.rawsource for ref in old_foot_refs]
                 new_foot_ref_rawsources = [ref.rawsource for ref in new_foot_refs]
-                logger.warning('inconsistent footnote references in translated message.' +
-                               ' original: {0}, translated: {1}'
+                logger.warning(__('inconsistent footnote references in translated message.' +
+                                  ' original: {0}, translated: {1}')
                                .format(old_foot_ref_rawsources, new_foot_ref_rawsources),
                                location=node)
             old_foot_namerefs = {}  # type: Dict[unicode, List[nodes.footnote_reference]]
@@ -289,8 +308,14 @@ class Locale(SphinxTransform):
                 new['ids'] = old['ids']
                 for id in new['ids']:
                     self.document.ids[id] = new
-                list_replace_or_append(
-                    self.document.autofootnote_refs, old, new)
+
+                if new['auto'] == 1:
+                    # autofootnote_refs
+                    list_replace_or_append(self.document.autofootnote_refs, old, new)
+                else:
+                    # symbol_footnote_refs
+                    list_replace_or_append(self.document.symbol_footnote_refs, old, new)
+
                 if refname:
                     list_replace_or_append(
                         self.document.footnote_refs.setdefault(refname, []),
@@ -312,8 +337,8 @@ class Locale(SphinxTransform):
             if len(old_refs) != len(new_refs):
                 old_ref_rawsources = [ref.rawsource for ref in old_refs]
                 new_ref_rawsources = [ref.rawsource for ref in new_refs]
-                logger.warning('inconsistent references in translated message.' +
-                               ' original: {0}, translated: {1}'
+                logger.warning(__('inconsistent references in translated message.' +
+                                  ' original: {0}, translated: {1}')
                                .format(old_ref_rawsources, new_ref_rawsources),
                                location=node)
             old_ref_names = [r['refname'] for r in old_refs]
@@ -339,20 +364,20 @@ class Locale(SphinxTransform):
                     'refname' in node
             old_foot_refs = node.traverse(is_refnamed_footnote_ref)
             new_foot_refs = patch.traverse(is_refnamed_footnote_ref)
-            refname_ids_map = {}
+            refname_ids_map = {}  # type: Dict[unicode, List[unicode]]
             if len(old_foot_refs) != len(new_foot_refs):
                 old_foot_ref_rawsources = [ref.rawsource for ref in old_foot_refs]
                 new_foot_ref_rawsources = [ref.rawsource for ref in new_foot_refs]
-                logger.warning('inconsistent footnote references in translated message.' +
-                               ' original: {0}, translated: {1}'
+                logger.warning(__('inconsistent footnote references in translated message.' +
+                                  ' original: {0}, translated: {1}')
                                .format(old_foot_ref_rawsources, new_foot_ref_rawsources),
                                location=node)
             for old in old_foot_refs:
-                refname_ids_map[old["refname"]] = old["ids"]
+                refname_ids_map.setdefault(old["refname"], []).append(old["ids"])
             for new in new_foot_refs:
                 refname = new["refname"]
-                if refname in refname_ids_map:
-                    new["ids"] = refname_ids_map[refname]
+                if refname_ids_map.get(refname):
+                    new["ids"] = refname_ids_map[refname].pop(0)
 
             # citation should use original 'ids'.
             def is_citation_ref(node):
@@ -365,16 +390,16 @@ class Locale(SphinxTransform):
             if len(old_cite_refs) != len(new_cite_refs):
                 old_cite_ref_rawsources = [ref.rawsource for ref in old_cite_refs]
                 new_cite_ref_rawsources = [ref.rawsource for ref in new_cite_refs]
-                logger.warning('inconsistent citation references in translated message.' +
-                               ' original: {0}, translated: {1}'
+                logger.warning(__('inconsistent citation references in translated message.' +
+                                  ' original: {0}, translated: {1}')
                                .format(old_cite_ref_rawsources, new_cite_ref_rawsources),
                                location=node)
             for old in old_cite_refs:
-                refname_ids_map[old["refname"]] = old["ids"]
+                refname_ids_map.setdefault(old["refname"], []).append(old["ids"])
             for new in new_cite_refs:
                 refname = new["refname"]
-                if refname in refname_ids_map:
-                    new["ids"] = refname_ids_map[refname]
+                if refname_ids_map.get(refname):
+                    new["ids"] = refname_ids_map[refname].pop()
 
             # Original pending_xref['reftarget'] contain not-translated
             # target name, new pending_xref must use original one.
@@ -385,8 +410,8 @@ class Locale(SphinxTransform):
             if len(old_refs) != len(new_refs):
                 old_ref_rawsources = [ref.rawsource for ref in old_refs]
                 new_ref_rawsources = [ref.rawsource for ref in new_refs]
-                logger.warning('inconsistent term references in translated message.' +
-                               ' original: {0}, translated: {1}'
+                logger.warning(__('inconsistent term references in translated message.' +
+                                  ' original: {0}, translated: {1}')
                                .format(old_ref_rawsources, new_ref_rawsources),
                                location=node)
 
@@ -438,7 +463,7 @@ class Locale(SphinxTransform):
                     msg_parts = split_index_msg(type, msg)
                     msgstr_parts = []
                     for part in msg_parts:
-                        msgstr = catalog.gettext(part)
+                        msgstr = catalog.gettext(part)  # type: ignore
                         if not msgstr:
                             msgstr = part
                         msgstr_parts.append(msgstr)
@@ -450,6 +475,7 @@ class Locale(SphinxTransform):
 
         # remove translated attribute that is used for avoiding double translation.
         def has_translatable(node):
+            # type: (nodes.Node) -> bool
             return isinstance(node, nodes.Element) and 'translated' in node
         for node in self.document.traverse(has_translatable):
             node.delattr('translated')
