@@ -12,24 +12,25 @@ from __future__ import absolute_import
 
 import re
 from contextlib import contextmanager
-from typing import TYPE_CHECKING
 
 from docutils.parsers.rst import roles
 from docutils.parsers.rst.languages import en as english
 from docutils.utils import Reporter
 
+from sphinx.locale import __
 from sphinx.util import logging
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Generator  # NOQA
 
-symbols_re = re.compile(r'([!--/:-@\[-`{-~])')  # symbols without dot(0x2e)
+symbols_re = re.compile(r'([!-\-/:-@\[-`{-~])')  # symbols without dot(0x2e)
 logger = logging.getLogger(__name__)
 
 
 def escape(text):
     # type: (unicode) -> unicode
-    text = symbols_re.sub(r'\\\1', text)  # type: ignore
+    text = symbols_re.sub(r'\\\1', text)
     text = re.sub(r'^\.', r'\.', text)  # escape a dot at top
     return text
 
@@ -43,7 +44,7 @@ def default_role(docname, name):
         if role_fn:
             roles._roles[''] = role_fn
         else:
-            logger.warning('default role %s not found', name, location=docname)
+            logger.warning(__('default role %s not found'), name, location=docname)
 
     yield
 
