@@ -12,7 +12,6 @@ import os
 import re
 import textwrap
 from itertools import groupby
-from typing import TYPE_CHECKING
 
 from docutils import nodes, writers
 from docutils.utils import column_width
@@ -22,7 +21,8 @@ from sphinx import addnodes
 from sphinx.locale import admonitionlabels, _
 from sphinx.util import logging
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Callable, Dict, List, Tuple, Union  # NOQA
     from sphinx.builders.text import TextBuilder  # NOQA
 
@@ -251,10 +251,6 @@ class TextTranslator(nodes.NodeVisitor):
                                  for line in lines)
         # XXX header/footer?
 
-    def visit_highlightlang(self, node):
-        # type: (nodes.Node) -> None
-        raise nodes.SkipNode
-
     def visit_section(self, node):
         # type: (nodes.Node) -> None
         self._title_char = self.sectionchars[self.sectionlevel]
@@ -987,10 +983,6 @@ class TextTranslator(nodes.NodeVisitor):
         # type: (nodes.Node) -> None
         raise nodes.SkipNode
 
-    def visit_substitution_definition(self, node):
-        # type: (nodes.Node) -> None
-        raise nodes.SkipNode
-
     def visit_pending_xref(self, node):
         # type: (nodes.Node) -> None
         pass
@@ -1183,13 +1175,19 @@ class TextTranslator(nodes.NodeVisitor):
 
     def visit_math(self, node):
         # type: (nodes.Node) -> None
-        logger.warning('using "math" markup without a Sphinx math extension '
-                       'active, please use one of the math extensions '
-                       'described at http://sphinx-doc.org/ext/math.html',
-                       location=(self.builder.current_docname, node.line))
-        raise nodes.SkipNode
+        pass
 
-    visit_math_block = visit_math
+    def depart_math(self, node):
+        # type: (nodes.Node) -> None
+        pass
+
+    def visit_math_block(self, node):
+        # type: (nodes.Node) -> None
+        self.new_state()
+
+    def depart_math_block(self, node):
+        # type: (nodes.Node) -> None
+        self.end_state()
 
     def unknown_visit(self, node):
         # type: (nodes.Node) -> None
